package com.ruoyi.model.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.model.domain.AppletIcon;

/**
 * 跳转图标菜单Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-30
 */
public interface AppletIconMapper extends BaseMapper<AppletIcon> {
    /**
     * 查询跳转图标菜单
     * 
     * @param id 跳转图标菜单主键
     * @return 跳转图标菜单
     */
    public AppletIcon selectAppletIconById(Long id);

    /**
     * 查询跳转图标菜单列表
     * 
     * @param appletIcon 跳转图标菜单
     * @return 跳转图标菜单集合
     */
    public List<AppletIcon> selectAppletIconList(AppletIcon appletIcon);

    /**
     * 新增跳转图标菜单
     * 
     * @param appletIcon 跳转图标菜单
     * @return 结果
     */
    public int insertAppletIcon(AppletIcon appletIcon);

    /**
     * 修改跳转图标菜单
     * 
     * @param appletIcon 跳转图标菜单
     * @return 结果
     */
    public int updateAppletIcon(AppletIcon appletIcon);

    /**
     * 删除跳转图标菜单
     * 
     * @param id 跳转图标菜单主键
     * @return 结果
     */
    public int deleteAppletIconById(Long id);

    /**
     * 批量删除跳转图标菜单
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppletIconByIds(Long[] ids);
}
